@@ -1,4 +1,4 @@
-/*	$OpenBSD: output-ometric.c,v 1.3 2023/04/26 16:32:41 claudio Exp $ */
+/*	$OpenBSD: output-ometric.c,v 1.5 2023/06/29 14:33:35 tb Exp $ */
 /*
  * Copyright (c) 2022 Claudio Jeker <claudio@openbsd.org>
  *
@@ -83,11 +83,7 @@ set_common_stats(const struct repotalstats *in, struct ometric *metric,
 	ometric_set_int_with_labels(metric, in->vaps_uniqs,
 	    OKV("type", "state"), OKV("vap", "unique"), ol);
 	ometric_set_int_with_labels(metric, in->vaps_pas,
-	    OKV("type", "state"), OKV("vap providers", "both"), ol);
-	ometric_set_int_with_labels(metric, in->vaps_pas4,
-	    OKV("type", "state"), OKV("vap providers", "IPv4 only"), ol);
-	ometric_set_int_with_labels(metric, in->vaps_pas6,
-	    OKV("type", "state"), OKV("vap providers", "IPv6 only"), ol);
+	    OKV("type", "state"), OKV("vap providers", "total"), ol);
 }
 
 static void
@@ -216,7 +212,6 @@ output_ometric(FILE *out, struct vrp_tree *vrps, struct brk_tree *brks,
 	repo_stats_collect(repo_stats, NULL);
 	set_common_stats(&st->repo_tal_stats, rpki_obj, NULL);
 
-	ometric_set_int(rpki_repo, st->repos, NULL);
 	ometric_set_int_with_labels(rpki_repo, st->rsync_repos,
 	    OKV("type", "state"), OKV("rsync", "synced"), NULL);
 	ometric_set_int_with_labels(rpki_repo, st->rsync_fails,
